Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(186)

Unified Diff: runtime/vm/raw_object_snapshot.cc

Issue 311963002: In class Function replace current code field with current instruction field, that way we save one l… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/raw_object.h ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object_snapshot.cc
===================================================================
--- runtime/vm/raw_object_snapshot.cc (revision 36916)
+++ runtime/vm/raw_object_snapshot.cc (working copy)
@@ -711,7 +711,7 @@
}
// Set up code pointer with the lazy-compile-stub.
- func.set_code(Code::Handle(StubCode::LazyCompile_entry()->code()));
+ func.SetInstructions(Code::Handle(StubCode::LazyCompile_entry()->code()));
return func.raw();
}
@@ -747,7 +747,7 @@
SnapshotWriterVisitor visitor(writer);
visitor.VisitPointers(from(), to_no_code());
// Write null for the code and unoptimized code.
writer->WriteVMIsolateObject(kNullObject);
writer->WriteVMIsolateObject(kNullObject);
}
@@ -747,7 +747,7 @@
SnapshotWriterVisitor visitor(writer);
visitor.VisitPointers(from(), to_no_code());
- // Write null for the code and unoptimized code.
+ // Write null for the instructions and unoptimized code.
writer->WriteVMIsolateObject(kNullObject);
writer->WriteVMIsolateObject(kNullObject);
« no previous file with comments | « runtime/vm/raw_object.h ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698